package com.akamai.media.demo4;


import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.SQLException;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteDatabase.CursorFactory;
import android.database.sqlite.SQLiteOpenHelper;
import android.util.Log;

public class PlayerVideosDB 
{
	  private static final String DATABASE_NAME = "videos_db.db";
	  private static final String DATABASE_TABLE = "videos";
	  private static final int DATABASE_VERSION = 1;
	 
	  // The index (key) column name for use in where clauses.
	  public static final String KEY_ID="_id";

	  // The name and column index of each column in your database.
	  public static final String KEY_NAME="name"; 
	  public static final int NAME_COLUMN = 1;

	  public static final String KEY_URL="url"; 
	  public static final int URL_COLUMN = 2;

	  // SQL Statement to create a new database.
	  private static final String DATABASE_CREATE = "create table " + 
	    DATABASE_TABLE + " (" + KEY_ID + 
	    " integer primary key autoincrement, " +
	    KEY_NAME + " text not null, " +
	    KEY_URL + " text not null);";

	  // Variable to hold the database instance
	  private SQLiteDatabase db;
	  // Context of the application using the database.
	  private final Context context;
	  // Database open/upgrade helper
	  private PlayerVideosDbHelper dbHelper;

	  public PlayerVideosDB(Context _context) 
	  {
	    context = _context;
	    dbHelper = new PlayerVideosDbHelper(context, DATABASE_NAME, null, DATABASE_VERSION);
	  }

	  public PlayerVideosDB open() throws SQLException 
	  {
	    db = dbHelper.getWritableDatabase();
	    //dbHelper.onUpgrade(db, 0, 1);
	    return this;
	  }

	  public void close() 
	  {
	      db.close();
	  }

	  public long insertEntry(VideoObject _myObject) 
	  {
		  return insertEntry(_myObject.mName, _myObject.mUrl);
	  }
	  
	  public long insertEntry(String _name, String _url) 
	  {
		  ContentValues cv = new ContentValues();   
          cv.put(KEY_NAME, _name);   
          cv.put(KEY_URL, _url);
          
		  return db.insert(DATABASE_TABLE, null, cv);
      }

	  public boolean removeEntry(long _rowIndex) 
	  {
	    return db.delete(DATABASE_TABLE, KEY_ID + "=" + _rowIndex, null) > 0;
	  }
	  
	  public boolean removeEntryByUrl(String _url)
	  {
		  return db.delete(DATABASE_TABLE, KEY_URL + "='" + _url+"'", null) > 0;
	  }

	  public Cursor getAllEntries () 
	  {
	    return db.query(DATABASE_TABLE, new String[] {KEY_ID, KEY_NAME, KEY_URL}, 
	                    null, null, null, null, null);
	  }

	  

	  private static class PlayerVideosDbHelper extends SQLiteOpenHelper 
	  {
		  
		Context mContext;
	    public PlayerVideosDbHelper(Context context, String name, 
	                      CursorFactory factory, int version) 
	    {
	      super(context, name, factory, version);
	      mContext = context;
	    }

	    // Called when no database exists in disk and the helper class needs
	    // to create a new one. 
	    @Override
	    public void onCreate(SQLiteDatabase _db) 
	    {
	      _db.execSQL(DATABASE_CREATE);
	      
	      loadInitialData(_db);
	    }
	    
	    
	    private void loadInitialData(SQLiteDatabase _db)
		{
	    	String names[] = mContext.getResources().getStringArray(R.array.urls_display);
	    	String urls[] = mContext.getResources().getStringArray(R.array.urls_data);
	    	
	    	if(names.length > 0)
	    	{
	    		for(int i=0;i<names.length;i++)
	    		{
	    			_db.execSQL(String.format("insert into %s (%s,%s) values ('%s','%s');", DATABASE_TABLE, KEY_NAME, KEY_URL, names[i], urls[i]));
	    		}
	    	}
	    	
		}

	    // Called when there is a database version mismatch meaning that the version
	    // of the database on disk needs to be upgraded to the current version.
	    @Override
	    public void onUpgrade(SQLiteDatabase _db, int _oldVersion, int _newVersion) 
	    {
	      // Log the version upgrade.
	      Log.w("PlayerVideosDbHelper", "Upgrading from version " + 
	                             _oldVersion + " to " +
	                             _newVersion + ", which will destroy all old data");
	        
	      // Upgrade the existing database to conform to the new version. Multiple 
	      // previous versions can be handled by comparing _oldVersion and _newVersion
	      // values.

	      // The simplest case is to drop the old table and create a new one.
	      _db.execSQL("DROP TABLE IF EXISTS " + DATABASE_TABLE);
	      // Create a new one.
	      onCreate(_db);
	      }
	  }
}
